@@ -5,7 +5,7 @@ use 5.006;
 use strict;
 use warnings;
 
-use version; our $VERSION = qv('v1.0.1');
+use version; our $VERSION = qv('v1.0.2');
 
 use List::MoreUtils qw{ any };
 
@@ -14,7 +14,10 @@ use base 'Perl::Critic::Policy';
 
 my $ENCODING_REGEX = qr/ ^ =encoding \s+ utf8 /xms;
 my $DESCRIPTION    = 'POD does not include "=encoding utf8" declaration';
-my $EXPLANATION    = 'Need to ensure that POD processors understand that the documentation may contain Unicode';
+## no critic (ValuesAndExpressions::RestrictLongStrings)
+my $EXPLANATION    =
+    'Need to ensure that POD processors understand that the documentation may contain Unicode';
+## use critic
 
 sub supported_parameters { return ();                  }
 sub default_severity     { return $SEVERITY_MEDIUM;    }
@@ -52,7 +55,7 @@ This policy is part of L<Perl::Critic::Swift>.
 =head1 VERSION
 
 This document describes
-Perl::Critic::Policy::Documentation::RequirePODUseEncodingUTF8 version 1.0.1.
+Perl::Critic::Policy::Documentation::RequirePODUseEncodingUTF8 version 1.0.2.
 
 
 =head1 SYNOPSIS
@@ -112,7 +115,8 @@ Elliot Shank  C<< <perl@galumph.com> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright ©2007, Elliot Shank C<< <perl@galumph.com> >>. All rights reserved.
+Copyright ©2007-2008, Elliot Shank C<< <perl@galumph.com> >>. All rights
+reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself. See L<perlartistic>.
